#!/usr/bin/env bash
#-----------------------------------------------------------------------------
# Project  ELE8304 : Circuits intégrés à très grande échelle
#-----------------------------------------------------------------------------
# File     setup.sh
# Authors  Mickael Fiorentino <mickael.fiorentino@polymtl.ca>
#          Yann Roberge        <yann.roberge@polymtl.ca>
# Lab      GRM - Polytechnique Montréal
# Date     <2024-01-01 Mon>
#-----------------------------------------------------------------------------
# Brief    Script de configuration de l'environnement
#          - Environnement CMC       -> ENLEVÉ
#          - Hiérarchie du projet
#          - kit GPDK45              -> ENLEVÉ
#          - Outils Cadence & Mentor -> ENLEVÉ
#
# Le script de Mikael, moins les outils Cadence, juste setup la hiérarchie du
# projet et le compilateur RISC-V 32b
#-----------------------------------------------------------------------------

#-----------------------------------------------------------------------------
# CONFIGURATION
#-----------------------------------------------------------------------------
export PROJECT_HOME=$(pwd)

# setup.sh doit être lancé depuis la racine du projet
if [ ! -f ${PROJECT_HOME}/setup.sh ]; then
    echo "ERROR: setup.sh doit être lancé depuis la racine du projet"
    exit 1
fi

#-----------------------------------------------------------------------------
# HIERARCHIE DU PROJET
#-----------------------------------------------------------------------------
export DOC_DIR=${PROJECT_HOME}/doc
export ASM_DIR=${PROJECT_HOME}/asm
export SRC_DIR=${PROJECT_HOME}/sources
export CONST_DIR=${PROJECT_HOME}/constraints
export SCRIPTS_DIR=${PROJECT_HOME}/scripts
export SIM_DIR=${PROJECT_HOME}/simulation
export IMP_DIR=${PROJECT_HOME}/implementation
export SYN_DIR=${IMP_DIR}/syn
export SYN_NET_DIR=${SYN_DIR}/netlist
export SYN_REP_DIR=${SYN_DIR}/reports
export SYN_LOG_DIR=${SYN_DIR}/logs
export ATPG_DIR=${IMP_DIR}/atpg
export PNR_DIR=${IMP_DIR}/pnr
export PNR_NET_DIR=${PNR_DIR}/netlist
export PNR_REP_DIR=${PNR_DIR}/reports

#-----------------------------------------------------------------------------
# CONFIGURATION DES OUTILS
#-----------------------------------------------------------------------------

# GCC
# if ( `echo $PATH | grep -c gcc-9.2.0-rv32im` == 0 ) then
#     source /users/support/config/gcc/gcc920-riscv
# endif

# MODELSIM
source $HOME/Programmes/Quartus/setup.sh
alias vsim="vsim -64"

